# mypy-boto3-schemas

[![PyPI - mypy-boto3-schemas](https://img.shields.io/pypi/v/mypy-boto3-schemas.svg?color=blue)](https://pypi.org/project/mypy-boto3-schemas)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-schemas.svg?color=blue)](https://pypi.org/project/mypy-boto3-schemas)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.Schemas 1.14.39](https://boto3.amazonaws.com/v1/documentation/api/1.14.39/reference/services/schemas.html#Schemas) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.2.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

## How to install

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `Schemas` service.

```bash
python -m pip install boto3-stubs[schemas]
```

## How to use

### Client annotations

`SchemasClient` provides annotations for `boto3.client("schemas")`.

```python
import boto3

from mypy_boto3_schemas import SchemasClient
from mypy_boto3_schemas.paginator import (
    ListDiscoverersPaginator,
    ListRegistriesPaginator,
    ListSchemasPaginator,
    ListSchemaVersionsPaginator,
    SearchSchemasPaginator,
)
from mypy_boto3_schemas.type_defs import DiscovererSummaryTypeDef, ...
from mypy_boto3_schemas.waiter import CodeBindingExistsWaiter

client: SchemasClient = boto3.client("schemas")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: SchemasClient = session.client("schemas")
```

### Paginators annotations

`mypy_boto3_schemas.paginator` module contains type annotations for all paginators.

```python

client: SchemasClient = boto3.client("schemas")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_discoverers_paginator: ListDiscoverersPaginator = client.get_paginator("list_discoverers")
list_registries_paginator: ListRegistriesPaginator = client.get_paginator("list_registries")
list_schema_versions_paginator: ListSchemaVersionsPaginator = client.get_paginator("list_schema_versions")
list_schemas_paginator: ListSchemasPaginator = client.get_paginator("list_schemas")
search_schemas_paginator: SearchSchemasPaginator = client.get_paginator("search_schemas")
```


### Waiters annotations

`mypy_boto3_schemas.waiter` module contains type annotations for all waiters.

```python

client: SchemasClient = boto3.client("schemas")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
code_binding_exists_waiter: CodeBindingExistsWaiter = client.get_waiter("code_binding_exists")
```





### Typed dictionations

`mypy_boto3_schemas.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python

def get_structure() -> DiscovererSummaryTypeDef:
    return {
      ...
    }
```


## Dynamic type annotations

`mypy_boto3` command generates `boto3.client/resource` type annotations for
`mypy_boto3_schemas` and other installed services.

```bash
# Run this command after you add or remove service packages
python -m mypy_boto3
```

Generated type annotations provide overloads for `boto3.client` and `boto3.resource`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully if you have many services installed
- `VSCode` does not currently support function overloads, use explicit type annotations

```python

# Type is discovered correctly by mypy and PyCharm
# VSCode still needs explicit type annotations
client = boto3.client("schemas")

session_client = boto3.Session().client("schemas")
```
